#! /usr/bin/perl -I/usr/local/processing/bin -w

use File::Basename;
use tr_coord;

# ----------------------- help sub ------------------------------
sub print_help {
@me = split(/\//,$0);
print "
$me[$#me] -i inpXYZser [-o outNEUser]

	convert xyz tablet series into neu series

	-i inpXYZser
	-o outNEUser
	NOTE: inpXYZser format:
SITE_ID	X	Y	Z	X_SIG	Y_SIG	Z_SIG	XY_CORR	XZ_CORR	YZ_CORR	YEAR_DOY
pin10000	-2369510.3717	-4761207.1464	3511396.1411	0.0129	0.0233	0.0163	0.6568	-0.7148	-0.7764	1994 003

		
	by pfang\@ucsd.edu ver.20140820\n";
}
# ---------------------- end help sub ----------------------------

my $matlab = '/shared/apps/matlab/bin/matlab';
my @matfunc = ('/shared/gpsproc/src/bin/xyz2llh.m',
'/shared/gpsproc/src/bin/geodetic297/geodetic/cct2clg.m',
'/shared/gpsproc/src/bin/geodetic297/geodetic/rotct2lg.m');
my $outSer = '';
my ($inpSer,$headtxt,$sID);
my (@val);

# ----------------------- main -----------------------------------
# sort command line arguments
if ($#ARGV <= -1) { # print help text
	&print_help;
	exit();
}
while ($#ARGV >= 0) {
	if ($ARGV[0] eq "-i") { # get input file
		$inpSer = $ARGV[1];
	}
	if ($ARGV[0] eq "-o") { # get output file
		$outSer = $ARGV[1];
	}
	shift(@ARGV);
}

if ($outSer eq "") {
	$outSer = $inpSer;
	$outSer =~ s/xyz/neu/;
}

foreach my $f (@matfunc) {
	system "ln -sf $f .";
}

# read in xyz sigma correlation and date
open(OUT,">xyz.ser") || die "$0: Unable to create xyz.ser\n";
open(INP,"<$inpSer") || die "$0: $inpSer not found\n";
$headtxt = <INP>;
while(<INP>) {
	@val = split(/\s+/,$_);
	$sID = $val[0];
	# dump out xyz sigma correlation and date without siteID
	shift @val;
	print OUT "@val\n";
}
close(INP);
close(OUT);

# create matlab script
open(MAT,">xyzSerTab2neuSer.m");
print MAT "sid = '$sID';\n";
#print MAT "r2d = pi/180.;\n";
print MAT "fid = fopen('neuSer.$sID.txt','w');\n";
print MAT "fprintf(fid,'SITE_ID dN      dE      dH     N_SIG   E_SIG   H_SIG   NE_CORR NH_CORR EH_CORR YEAR DOY\\n');\n";
# read xyz(1-3) sigma(4-6) correlation(7-9) date(10-11) into an array(xyz)
print MAT "load xyz.ser\n";
print MAT "nl = length(xyz(:,1));\n";
print MAT "for i=1:nl\n";
# comput xyz differences with respect to first xyz
print MAT "\tdxyz = [xyz(i,1)-xyz(1,1);xyz(i,2)-xyz(1,2);xyz(i,3)-xyz(1,3)];\n";
# comput lat lon h (wgs) using xyz
print MAT "\t[lat,lon,h] = xyz2llh(xyz(i,1),xyz(i,2),xyz(i,3));\n";
# form rotation matrix
print MAT "\tJi=rotct2lg(lat,lon);\n";
# rotate xyz differences into neu differences
print MAT "\tdneu = Ji*dxyz;\n";
# form xyz covariance (before convert correlation to covariance) 
# sigX*2 corXY corXZ
# corYX sigY*2 corYZ
# corZX corZY sigZ*2
print MAT "\txyzcov = [xyz(i,4)*xyz(i,4) xyz(i,7) xyz(i,8);xyz(i,7) xyz(i,5)*xyz(i,5) xyz(i,9);xyz(i,8) xyz(i,9) xyz(i,6)*xyz(i,6)];\n";
# convert correlation to covariance using covXY = corXY*sigX*sigY
print MAT "\txyzcov(1,2) = xyzcov(1,2)*xyz(i,4)*xyz(i,5);\n";
print MAT "\txyzcov(1,3) = xyzcov(1,3)*xyz(i,4)*xyz(i,6);\n";
print MAT "\txyzcov(2,3) = xyzcov(2,3)*xyz(i,5)*xyz(i,6);\n";
print MAT "\txyzcov(2,1) = xyzcov(1,2);\n";
print MAT "\txyzcov(3,1) = xyzcov(1,3);\n";
print MAT "\txyzcov(3,2) = xyzcov(2,3);\n";
# perform transformation
print MAT "\tClg = cct2clg(xyzcov,lat,lon);\n";
# convert covariance to correlation (diagnal terms)
print MAT "\tClg(1,1) = sqrt(Clg(1,1));\n";
print MAT "\tClg(2,2) = sqrt(Clg(2,2));\n";
print MAT "\tClg(3,3) = sqrt(Clg(3,3));\n";
# convert covariance to correlation using corNE = covNE/(sigN*sigE)
print MAT "\tClg(1,2) = Clg(1,2)/(Clg(1,1)*Clg(2,2));\n";
print MAT "\tClg(1,3) = Clg(1,3)/(Clg(1,1)*Clg(3,3));\n";
print MAT "\tClg(2,3) = Clg(2,3)/(Clg(2,2)*Clg(3,3));\n";
print MAT "\tClg(2,1) = Clg(1,2);\n";
print MAT "\tClg(3,1) = Clg(1,3);\n";
print MAT "\tClg(3,2) = Clg(2,3);\n";
print MAT "\tfprintf(fid,'%s\\t%7.4f\\t%7.4f\\t%7.4f',sid,dneu);\n";
print MAT "\tfprintf(fid,'\\t%7.4f\\t%7.4f\\t%7.4f',Clg(1,1),Clg(2,2),Clg(3,3));\n";
print MAT "\tfprintf(fid,'\\t%7.4f\\t%7.4f\\t%7.4f',Clg(1,2),Clg(1,3),Clg(2,3));\n";
print MAT "\tfprintf(fid,'\\t%4d %03.0f\\n',xyz(i,10),xyz(i,11));\n";
print MAT "end\n";
print MAT "fclose(fid);\n";
close(MAT);
system "$matlab -nosplash -nodisplay -nojvm < xyzSerTab2neuSer.m\n";

# ----------------------- end of main --------------------------
